/************************************************************************

   File:		testRD11.c

   Author(s):		Robert Sim

   Created:		22 Oct 1999

   Last Revision:	$Date$

   Description:	

   $Revision$

   $Log$

	
   Copyright (c) 1999 by Robert Sim, Centre for Intelligent Machines,
   McGill University, Montreal, QC.  Please see the copyright notice
   included in this distribution for full details.

 ***********************************************************************/

#define TESTRD11_C

#include "RD11.h"
#include <stdlib.h>
#include <stdio.h>
int main (int argc, char ** argv) {
  char Name[10];
  char Value[10];
  char message[20];
  int i=0,j;
  int nSonar=0;
  float * Data;
  RD_Pose pose;


  if (argc<2) {
    fprintf(stderr, "Usage: %s num_loops\n", argv[0]);
    exit(1);
  }

  sprintf(Name, "robbo");
  /* Connect.  Default host and port are the local host, and port 5090.
     If you use different values, be sure to pass the port number as a string (eg, char* port="5090") */
  if (RD_Connect(NULL, NULL)<0) { 
    fprintf(stderr,"Unable to connect to RD11 locally\n");
    exit(1);
  }

  /* clean up any previous connections. */
  RD_Send_Command("clear all", NULL);
  RD_Send_Command("destroy all", NULL);

  RD_Create(RD_SCOUT_SIMULATOR, Name, 0);

  /* simRealTime controls whether actions are performed in real time
     or not (turn it off to speed up your simulations) */
  sprintf(Value, "1");
  RD_Set_Variable("simRealTime", Value);

  sprintf(message, "%s.nSonar", Name);
  RD_Get_Variable(message, Value);
  fprintf(stderr, "%s value is %s\n", message, Value);
  nSonar=atoi(Value);

  /* handy way to make a random map is with makemap.  Pose (30,30) is
     always guaranteed to be safe for the robot to be initialized
     there. */
  RD_Send_Command("makemap",NULL);  /* the second arg of Send_Command
					 is unused */

  pose.X=30;
  pose.Y=30;
  pose.Theta=0;
  RD_Set_Pose(Name, &pose);

  /* The sonar array is 5 values per transducer (nSonar transducers) */
  Data=(float*)malloc(nSonar*5*sizeof(float));
  while(i++<atoi(argv[1])) {
    float x,y;
    printf("Loop: %d\n",i);
    x=10;
    y=10;
    RD_Rel_Move(Name, &x, &y, 0, 0);
    RD_Sonar(Name, 0, Data); 
    fprintf(stderr, "Scan: %d\n", i);
    for (j=0; j<nSonar; j++) {
      /* Pose: X,Y,Theta of the robot in world coords.
	 Ping: R,Theta of the ping relative to the robot.  Don't
	 forget that the robot's forward direction corresponds to its
	 x axis! That is, the abs theta of a ping is the sum of the
	 pose theta and the ping theta */
      fprintf(stderr, "Pose (%.2f, %.2f, %.2f) Ping: %f %f\n", 
	      Data[5*j], Data[5*j+1], Data[5*j+2], Data[5*j+3], Data[5*j+4]); 
    }
  }

  RD_Destroy(Name);
  RD_Disconnect();
}
